@@ -1,11 +1,13 @@
 import logging
 from typing import Iterator, Callable, Union, Optional, List
+
 from .rest_adapter import RestAdapter
 from .exceptions import AeripyException
 from .models import *
 from .endpoints import API_PATH
 from .models import SystemInfo, School
-from .util import snake_case_keys, camel_case_keys
+from .utils import snake_case_keys, camel_case_keys
+
 
 class AeripyApi:
     def __init__(self, hostname: str = "demo.aeries.net/aeries/api", api_key: str = '477abe9e7d27439681d62f4e0de1f5e1',
